# -*- coding: utf-8 -*-

"""
    eve.io
    ~~~~~~

    This package implements the data layers supported by Eve.

    :copyright: (c) 2013 by Nicola Iarocci.
    :license: BSD, see LICENSE for more details.
"""

# flake8: noqa
from eve.io.base import DataLayer, ConnectionException
